pub struct EpisodeSimplified {Show 15 fields
pub audio_preview_url: Option<String>,
pub description: String,
pub duration: Duration,
pub explicit: bool,
pub external_urls: HashMap<String, String>,
pub id: String,
pub images: Vec<Image>,
pub is_externally_hosted: bool,
pub is_playable: bool,
pub languages: Vec<String>,
pub name: String,
pub release_date: NaiveDate,
pub release_date_precision: DatePrecision,
pub resume_point: Option<ResumePoint>,
pub item_type: TypeEpisode,
}Expand description
A simplified episode object.
Fields
audio_preview_url: Option<String>The URL of a 30 second MP3 preview of the episode, or None.
description: StringA description of the episode.
duration: DurationThe length of the episode.
explicit: boolWhether the episode is explicit.
external_urls: HashMap<String, String>Externals URLs for this episode.
id: StringThe Spotify ID for this episode.
images: Vec<Image>The cover art for this episode in sizes, widest first.
is_externally_hosted: boolWhether the episode is hosted outside of Spotify’s CDN.
is_playable: boolWhether the episode is playable in the given market.
languages: Vec<String>The list of languages used in this episode.
name: StringThe name of the episode.
release_date: NaiveDateWhen the episode was released.
release_date_precision: DatePrecisionHow precise the release date is: precise to the year, month or day.
resume_point: Option<ResumePoint>The user’s most recent position in the episode. None if there is no user.
item_type: TypeEpisodeThe item type; episode.