pub struct PlaylistSimplified {
pub tracks: Tracks,
pub collaborative: bool,
pub external_urls: HashMap<String, String>,
pub id: String,
pub images: Vec<Image>,
pub name: String,
pub owner: UserSimplified,
pub public: Option<bool>,
pub snapshot_id: String,
pub item_type: TypePlaylist,
}Expand description
A simplified playlist object.
Fields
tracks: TracksThe number of tracks in the playlist.
collaborative: boolWhether the owner allows other people to modify the playlist. Always is false from a search context.
external_urls: HashMap<String, String>Known external URLs for this playlist.
id: StringThe Spotify ID for this playlist.
images: Vec<Image>Images for the playlist. It may be empty, or contain up to three images, in descending order of size. The URLs are temporary and will expire in less than a day.
name: StringThe name of the playlist.
owner: UserSimplifiedThe user who owns the playlist. This is a UserPublic
according to the documentation, but in practice it is not.
public: Option<bool>Whether the playlist is public; None if not relevant.
snapshot_id: StringThe version identifier of the playlist.
item_type: TypePlaylistThe item type; playlist.