pub struct Show {Show 14 fields
pub episodes: Page<EpisodeSimplified>,
pub available_markets: Vec<String>,
pub copyrights: Vec<Copyright>,
pub description: String,
pub explicit: bool,
pub external_urls: HashMap<String, String>,
pub id: String,
pub images: Vec<Image>,
pub is_externally_hosted: Option<bool>,
pub languages: Vec<String>,
pub media_type: String,
pub name: String,
pub publisher: String,
pub item_type: TypeShow,
}Expand description
A show object.
Fields
episodes: Page<EpisodeSimplified>A list of the show’s episodes.
available_markets: Vec<String>A list of countries in which the show can be played. These are ISO 3166 2-letter country codes.
copyrights: Vec<Copyright>The copyright statements of the show.
description: StringA description of the show.
explicit: boolWhether the show is explicit.
external_urls: HashMap<String, String>Known externals URLs for this show.
id: StringThe Spotify ID for this show.
images: Vec<Image>The cover art for the show in various sizes, widest first.
is_externally_hosted: Option<bool>Whether the episode is hosted outside of Spotify’s CDN. Can be None.
languages: Vec<String>The list of languages used in the show. These are ISO 639 codes.
media_type: StringThe media type of the show.
name: StringThe name of the show.
publisher: StringThe publisher of the show.
item_type: TypeShowThe item type; show.
Implementations